==> waypaper-1.9-py3-none-any.whl: waypaper/translation_en.py <==
"""English translations of the program interface"""

MSG_DESC = "GUI wallpaper setter for Wayland and X11. It works as a frontend for feh, swaybg, wallutils, and swww."
MSG_INFO = "For more information, visit:\nhttps://github.com/anufrievroman/waypaper"

MSG_ARG_HELP = "print version of the program"
MSG_ARG_FILL = "specify how to fill the screen with chosen image"
MSG_ARG_REST = "restore last wallpaper"
MSG_ARG_BACK = "specify which backend to use to set wallpaper"
MSG_ARG_RAND = "set a random wallpaper"

MSG_PATH = "Selected image path:"
MSG_SELECT = "Select"
MSG_REFRESH = "Refresh"
MSG_RANDOM = "Random"
MSG_EXIT = "Exit"
MSG_SUBFOLDERS = "Subfolders"
MSG_CHANGEFOLDER = "Change wallpaper folder"
MSG_CHOOSEFOLDER = "Please choose a folder"
MSG_CACHING = "Caching wallpapers..."
MSG_SETWITH = "Wallpaper was set with"

MSG_HELP = "Waypaper's hotkeys:\n\nhjkl - Navigation (←↓↑→)\n"
MSG_HELP += "g - Scroll to top\nG - Scroll to bottom\nR - Set random wallpaper\nr - Recache wallpapers\n"
MSG_HELP += "s - Include/exclude images in subfolders\n? - Help\nq - Exit\n\n"
MSG_HELP += MSG_INFO

ERR_CACHE = "Error deleting cache"
ERR_BACKEND = "Looks like none of the wallpaper backends is installed in the system.\n"
ERR_BACKEND += "Use your package manager to install at least one of these backends:\n\n"
ERR_BACKEND += "- swaybg (for Wayland)\n- swww (for Wayland)\n"
ERR_BACKEND += "- feh (for Xorg)\n- wallutils (for Xorg & Wayland)\n\n"
ERR_BACKEND += MSG_INFO
ERR_WALL = "Error changing wallpaper:"
ERR_NOTSUP = "The backend is not supported:"
ERR_DISP = "Error determining monitor names:"

==> waypaper-1.9.2-py3-none-any.whl: waypaper/translation_en.py <==
"""English translations of the program interface"""

MSG_DESC = "GUI wallpaper setter for Wayland and X11. It works as a frontend for feh, swaybg, wallutils, and swww."
MSG_INFO = "For more information, visit:\nhttps://github.com/anufrievroman/waypaper"

MSG_ARG_HELP = "print version of the program"
MSG_ARG_FILL = "specify how to fill the screen with chosen image"
MSG_ARG_REST = "restore last wallpaper"
MSG_ARG_BACK = "specify which backend to use to set wallpaper"
MSG_ARG_RAND = "set a random wallpaper"

MSG_PATH = "Selected image path:"
MSG_SELECT = "Select"
MSG_REFRESH = "Refresh"
MSG_RANDOM = "Random"
MSG_EXIT = "Exit"
MSG_SUBFOLDERS = "Subfolders"
MSG_CHANGEFOLDER = "Change wallpaper folder"
MSG_CHOOSEFOLDER = "Please choose a folder"
MSG_CACHING = "Caching wallpapers..."
MSG_SETWITH = "Wallpaper was set with"

MSG_HELP = "Waypaper's hotkeys:\n\nhjkl - Navigation (←↓↑→)\nf - Change wallpaper folder\n"
MSG_HELP += "g - Scroll to top\nG - Scroll to bottom\nR - Set random wallpaper\nr - Recache wallpapers\n"
MSG_HELP += "s - Include/exclude images in subfolders\n? - Help\nq - Exit\n\n"
MSG_HELP += MSG_INFO

ERR_CACHE = "Error deleting cache"
ERR_BACKEND = "Looks like none of the wallpaper backends is installed in the system.\n"
ERR_BACKEND += "Use your package manager to install at least one of these backends:\n\n"
ERR_BACKEND += "- swaybg (for Wayland)\n- swww (for Wayland)\n"
ERR_BACKEND += "- feh (for Xorg)\n- wallutils (for Xorg & Wayland)\n\n"
ERR_BACKEND += MSG_INFO
ERR_WALL = "Error changing wallpaper:"
ERR_NOTSUP = "The backend is not supported:"
ERR_DISP = "Error determining monitor names:"

TIP_SUBFOLDER = "Include/exclude images in subfolders"
TIP_REFRESH = "Recache the folder of images"
TIP_FILL = "Choose fill type"
TIP_BACKEND = "Choose backend"
TIP_SORTING = "Choose sorting type"
TIP_DISPLAY = "Choose display"
TIP_COLOR = "Choose background color"
TIP_RANDOM = "Set random wallpaper"
TIP_EXIT = "Exit the application"
